searchData={"content_type":"text/markdown","items":[{"doc":"A module for generating XML","ref":"XmlBuilder.html","title":"XmlBuilder","type":"module"},{"doc":"iex> XmlBuilder.document(:person) |> XmlBuilder.generate\n    \"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?>\\n \"\n\n    iex> XmlBuilder.document(:person, \"Josh\") |> XmlBuilder.generate\n    \"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?>\\n Josh \"\n\n    iex> XmlBuilder.document(:person) |> XmlBuilder.generate(format: :none)\n    \"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?> \"\n\n    iex> XmlBuilder.element(:person, \"Josh\") |> XmlBuilder.generate\n    \" Josh \"\n\n    iex> XmlBuilder.element(:person, %{occupation: \"Developer\"}, \"Josh\") |> XmlBuilder.generate\n    \" Josh \"","ref":"XmlBuilder.html#module-examples","title":"Examples - XmlBuilder","type":"module"},{"doc":"Creates a DOCTYPE declaration with a system or public identifier.","ref":"XmlBuilder.html#doctype/2","title":"XmlBuilder.doctype/2","type":"function"},{"doc":"Returns a `tuple` in the format `{:doctype, {:system, name, system_identifier}}`.\n\n```elixir\nimport XmlBuilder\n\ndocument([\n  doctype(\"greeting\", system: \"hello.dtd\"),\n  element(:person, \"Josh\")\n]) |> generate\n```\n\nOutputs\n\n```xml\n<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n<!DOCTYPE greeting SYSTEM \"hello.dtd\">\n Josh \n```","ref":"XmlBuilder.html#doctype/2-system-example","title":"System Example - XmlBuilder.doctype/2","type":"function"},{"doc":"Returns a `tuple` in the format `{:doctype, {:public, name, public_identifier, system_identifier}}`.\n\n```elixir\nimport XmlBuilder\n\ndocument([\n  doctype(\"html\", public: [\"-//W3C//DTD XHTML 1.0 Transitional//EN\",\n                \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\"]),\n  element(:html, \"Hello, world!\")\n]) |> generate\n```\n\nOutputs\n\n```xml\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n Hello, world! \n```","ref":"XmlBuilder.html#doctype/2-public-example","title":"Public Example - XmlBuilder.doctype/2","type":"function"},{"doc":"Generate an XML document.\n\nReturns a `binary`.","ref":"XmlBuilder.html#document/1","title":"XmlBuilder.document/1","type":"function"},{"doc":"iex> XmlBuilder.document(:person) |> XmlBuilder.generate\n    \"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?>\\n \"\n\n    iex> XmlBuilder.document(:person, %{id: 1}) |> XmlBuilder.generate\n    \"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?>\\n \"\n\n    iex> XmlBuilder.document(:person, %{id: 1}, \"some data\") |> XmlBuilder.generate\n    \"<?xml version=\\\"1.0\\\" encoding=\\\"UTF-8\\\"?>\\n some data \"","ref":"XmlBuilder.html#document/1-examples","title":"Examples - XmlBuilder.document/1","type":"function"},{"doc":"","ref":"XmlBuilder.html#document/2","title":"XmlBuilder.document/2","type":"function"},{"doc":"","ref":"XmlBuilder.html#document/3","title":"XmlBuilder.document/3","type":"function"},{"doc":"Create an XML element.\n\nReturns a `tuple` in the format `{name, attributes, content | list}`.","ref":"XmlBuilder.html#element/1","title":"XmlBuilder.element/1","type":"function"},{"doc":"iex> XmlBuilder.element(:person)\n    {:person, nil, nil}\n\n    iex> XmlBuilder.element(:person, \"data\")\n    {:person, nil, \"data\"}\n\n    iex> XmlBuilder.element(:person, %{id: 1})\n    {:person, %{id: 1}, nil}\n\n    iex> XmlBuilder.element(:person, %{id: 1}, \"data\")\n    {:person, %{id: 1}, \"data\"}\n\n    iex> XmlBuilder.element(:person, %{id: 1}, [XmlBuilder.element(:first, \"Steve\"), XmlBuilder.element(:last, \"Jobs\")])\n    {:person, %{id: 1}, [\n      {:first, nil, \"Steve\"},\n      {:last, nil, \"Jobs\"}\n    ]}","ref":"XmlBuilder.html#element/1-examples","title":"Examples - XmlBuilder.element/1","type":"function"},{"doc":"","ref":"XmlBuilder.html#element/2","title":"XmlBuilder.element/2","type":"function"},{"doc":"","ref":"XmlBuilder.html#element/3","title":"XmlBuilder.element/3","type":"function"},{"doc":"Generate a binary from an XML tree\n\nReturns a `binary`.","ref":"XmlBuilder.html#generate/2","title":"XmlBuilder.generate/2","type":"function"},{"doc":"iex> XmlBuilder.generate(XmlBuilder.element(:person))\n    \" \"\n\n    iex> XmlBuilder.generate({:person, %{id: 1}, \"Steve Jobs\"})\n    \" Steve Jobs \"\n\n    iex> XmlBuilder.generate({:name, nil, [{:first, nil, \"Steve\"}]}, format: :none)\n    \"  Steve  \"\n\n    iex> XmlBuilder.generate({:name, nil, [{:first, nil, \"Steve\"}]}, whitespace: \"\")\n    \" \\n Steve \\n \"\n\n    iex> XmlBuilder.generate({:name, nil, [{:first, nil, \"Steve\"}]})\n    \" \\n   Steve \\n \"\n\n    iex> XmlBuilder.generate(:xml_decl, encoding: \"ISO-8859-1\")\n    ~s|<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>|","ref":"XmlBuilder.html#generate/2-examples","title":"Examples - XmlBuilder.generate/2","type":"function"},{"doc":"Similar to `generate/2`, but returns `iodata` instead of a `binary`.","ref":"XmlBuilder.html#generate_iodata/2","title":"XmlBuilder.generate_iodata/2","type":"function"},{"doc":"iex> XmlBuilder.generate_iodata(XmlBuilder.element(:person))\n    [\"\", '<', \"person\", '/>']","ref":"XmlBuilder.html#generate_iodata/2-examples","title":"Examples - XmlBuilder.generate_iodata/2","type":"function"},{"doc":"Documentation for Elixir.XmlBuilder.Format.Indented","ref":"XmlBuilder.Format.Indented.html","title":"XmlBuilder.Format.Indented","type":"module"},{"doc":"","ref":"XmlBuilder.Format.Indented.html#indentation/2","title":"XmlBuilder.Format.Indented.indentation/2","type":"function"},{"doc":"","ref":"XmlBuilder.Format.Indented.html#line_break/0","title":"XmlBuilder.Format.Indented.line_break/0","type":"function"},{"doc":"Documentation for Elixir.XmlBuilder.Format.None","ref":"XmlBuilder.Format.None.html","title":"XmlBuilder.Format.None","type":"module"},{"doc":"","ref":"XmlBuilder.Format.None.html#indentation/2","title":"XmlBuilder.Format.None.indentation/2","type":"function"},{"doc":"","ref":"XmlBuilder.Format.None.html#line_break/0","title":"XmlBuilder.Format.None.line_break/0","type":"function"},{"doc":"XML Builder\n===========\n\n[![CI](https://github.com/joshnuss/xml_builder/workflows/mix/badge.svg)](https://github.com/joshnuss/xml_builder/actions)\n[![Module Version](https://img.shields.io/hexpm/v/xml_builder.svg)](https://hex.pm/packages/xml_builder)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/xml_builder/)\n[![Total Download](https://img.shields.io/hexpm/dt/xml_builder.svg)](https://hex.pm/packages/xml_builder)\n[![License](https://img.shields.io/hexpm/l/xml_builder.svg)](https://github.com/joshnuss/xml_builder/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/joshnuss/xml_builder.svg)](https://github.com/joshnuss/xml_builder/commits/master)","ref":"readme.html","title":"XML Builder","type":"extras"},{"doc":"An Elixir library for building XML. It is inspired by the late [Jim Weirich](https://github.com/jimweirich)'s awesome [builder](https://github.com/jimweirich/builder) library for Ruby.\n\nEach XML node is structured as a tuple of name, attributes map, and content/list.\n\n```elixir\n{name, attrs, content | list}\n```","ref":"readme.html#overview","title":"Overview - XML Builder","type":"extras"},{"doc":"Add dependency to your project's `mix.exs`:\n\n```elixir\ndef deps do\n  [{:xml_builder, \"~> 2.1\"}]\nend\n```","ref":"readme.html#installation","title":"Installation - XML Builder","type":"extras"},{"doc":"","ref":"readme.html#examples","title":"Examples - XML Builder","type":"extras"},{"doc":"Like ` Josh `, would look like:\n\n```elixir\n{:person, %{id: 12345}, \"Josh\"} |> XmlBuilder.generate\n```","ref":"readme.html#a-simple-element","title":"A simple element - XML Builder","type":"extras"},{"doc":"Like `  Josh  Nussbaum  `.\n\n```elixir\n{:person, %{id: 12345}, [{:first, nil, \"Josh\"}, {:last, nil, \"Nussbaum\"}]} |> XmlBuilder.generate\n```","ref":"readme.html#an-element-with-child-elements","title":"An element with child elements - XML Builder","type":"extras"},{"doc":"For more readability, you can use XmlBuilder's methods instead of creating tuples manually.\n\n```elixir\nXmlBuilder.document(:person, \"Josh\") |> XmlBuilder.generate\n```\n\nOutputs:\n\n```xml\n<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n Josh \n```\n\n#### Building up an element\n\nAn element can be built using multiple calls to the `element` function.\n\n```elixir\nimport XmlBuilder\n\ndef person(id, first, last) do\n  element(:person, %{id: id}, [\n    element(:first, first),\n    element(:last, last)\n  ])\nend\n\niex> [person(123, \"Steve\", \"Jobs\"),\n      person(456, \"Steve\", \"Wozniak\")] |> generate\n```\n\nOutputs.\n\n```xml\n \n   Steve \n   Jobs \n \n \n   Steve \n   Wozniak \n \n```\n\n#### Using keyed lists\n\nThe previous example can be simplified using a keyed list.\n\n```elixir\nimport XmlBuilder\n\ndef person(id, first, last) do\n  element(:person, %{id: id}, first: first,\n                              last: last)\nend\n\niex> person(123, \"Josh\", \"Nussbaum\") |> generate(format: :none)\n\"  Josh  Nussbaum  \"\n```\n\n#### Namespaces\n\nTo use a namespace, add an `xmlns` attribute to the root element.\n\nTo use multiple schemas, specify a `xmlns:nsName` attribute for each schema and use a colon `:` in the element name, ie `nsName:elementName`.\n\n```elixir\nimport XmlBuilder\n\niex> generate({:example, [xmlns: \"http://schemas.example.tld/1999\"], \"content\"})\n\" content \"\n\niex> generate({:\"nsName:elementName\", [\"xmlns:nsName\": \"http://schemas.example.tld/1999\"], \"content\"})\n\" content \"\n```","ref":"readme.html#convenience-functions","title":"Convenience Functions - XML Builder","type":"extras"},{"doc":"A DOCTYPE can be declared by applying the `doctype` function at the first position of a list of elements in a `document` definition:\n\n```elixir\nimport XmlBuilder\n\ndocument([\n  doctype(\"html\", public: [\"-//W3C//DTD XHTML 1.0 Transitional//EN\",\n                \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\"]),\n  element(:html, \"Hello, world!\")\n]) |> generate\n```\n\nOutputs.\n\n```xml\n<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n Hello, world! \n```","ref":"readme.html#doctype-declarations","title":"DOCTYPE declarations - XML Builder","type":"extras"},{"doc":"While the output is always UTF-8 and has to be converted in another place, you can override the encoding statement in the XML declaration with the `encoding` option.\n\n```elixir\nimport XmlBuilder\n\ndocument(:oldschool)\n|> generate(encoding: \"ISO-8859-1\")\n|> :unicode.characters_to_binary(:unicode, :latin1)\n```\n\nOutputs.\n\n```xml\n<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n \n```","ref":"readme.html#encoding","title":"Encoding - XML Builder","type":"extras"},{"doc":"While by default, output from `generate/2` is converted to `binary()`, you can use `generate_iodata/2` to skip this conversion. This can be convenient if you're using `IO.binwrite/2` on a `:raw` IO device, as these APIs can work with `iodata()` directly, leading to some performance gains.\n\nIn some scenarios, it may be beneficial to generate part of your XML upfront, for instance when generating a `sitemap.xml`, you may have shared fields for `author`. Instead of generating this each time, you could do the following:\n\n```elixir\nimport XmlBuilder\n\nentries = [%{title: \"Test\", url: \"https://example.org/\"}]\n\n# Generate static author data upfront\nauthor = generate_iodata(element(:author, [\n  element(:name, \"John Doe\"),\n  element(:uri, \"https://example.org/\")\n]))\n\nfile = File.open!(\"path/to/file\", [:raw])\n\nfor entry <- entries do\n  iodata =\n    generate_iodata(element(:entry, [\n      # Reuse the static pre-generated fields as-is\n      {:iodata, author},\n\n      # Dynamic elements are generated for each entry\n      element(:title, entry.title),\n      element(:link, entry.url)\n    ]))\n\n  IO.binwrite(file, iodata)\nend\n```","ref":"readme.html#using-iodata-directly","title":"Using `iodata()` directly - XML Builder","type":"extras"},{"doc":"XmlBuilder offers 3 distinct ways to control how content of tags is escaped and handled:\n\n- By default, any content is escaped, replacing reserved characters (`& \" ' < >`) with their equivalent entity (`&amp;` etc.)\n- If content is wrapped in `{:cdata, cdata}`, the content in `cdata` is wrapped with `<![CDATA[...]]>`, and not escaped. You should make sure the content itself does not contain `]]>`.\n- If content is wrapped in `{:safe, data}`, the content in `data` is not escaped, but will be stringified if not a bitstring. Use this option carefully. It may be useful when data is guaranteed to be safe (numeric data).\n- If content is wrapped in `{:iodata, data}`, either in the top level or within a list, the `data` is used as `iodata()`, and will not be escaped, indented or stringified. An example of this can be seen in the \"Using `iodata()` directly\" example above.","ref":"readme.html#escaping","title":"Escaping - XML Builder","type":"extras"},{"doc":"Should you need `standalone=\"yes\"` in the XML declaration, you can pass `standalone: true` as option to the `generate/2` call.\n\n```elixir\nimport XmlBuilder\n\ndocument(:outsider)\n|> generate(standalone: true)\n```\n\nOutputs.\n\n```xml\n<?xml version=\"1.0\" standalone=\"yes\"?>\n \n```\n\nIf otherwise you need `standalone =\"no\"` in the XML declaration, you can pass `standalone: false` as an option to the` generate / 2` call.\n\nOutputs.\n\n```xml\n<?xml version=\"1.0\" standalone=\"no\"?>\n \n```","ref":"readme.html#standalone","title":"Standalone - XML Builder","type":"extras"},{"doc":"To remove indentation, pass `format: :none` option to `XmlBuilder.generate/2`.\n\n```elixir\ndoc |> XmlBuilder.generate(format: :none)\n```\n\nThe default is to formatting with indentation, which is equivalent to `XmlBuilder.generate(doc, format: :indent)`.","ref":"readme.html#formatting","title":"Formatting - XML Builder","type":"extras"},{"doc":"This source code is licensed under the [MIT License](https://github.com/joshnuss/xml_builder/blob/master/LICENSE). Copyright (c) 2014-present, Joshua Nussbaum. All rights reserved.","ref":"readme.html#license","title":"License - XML Builder","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}